package com.example.shawarma.screens.orders

import androidx.compose.foundation.BorderStroke
import androidx.compose.foundation.background
import androidx.compose.foundation.layout.Arrangement
import androidx.compose.foundation.layout.Box
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.Row
import androidx.compose.foundation.layout.Spacer
import androidx.compose.foundation.layout.fillMaxSize
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.layout.height
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.layout.size
import androidx.compose.foundation.layout.width
import androidx.compose.foundation.lazy.LazyColumn
import androidx.compose.foundation.rememberScrollState
import androidx.compose.foundation.shape.RoundedCornerShape
import androidx.compose.foundation.verticalScroll
import androidx.compose.material.Button
import androidx.compose.material.ButtonDefaults
import androidx.compose.material.Card
import androidx.compose.material.Text
import androidx.compose.runtime.Composable
import androidx.compose.runtime.LaunchedEffect
import androidx.compose.runtime.mutableStateListOf
import androidx.compose.runtime.remember
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.draw.clip
import androidx.compose.ui.graphics.Color
import androidx.compose.ui.platform.LocalContext
import androidx.compose.ui.text.font.FontWeight
import androidx.compose.ui.unit.dp
import androidx.compose.ui.unit.sp
import androidx.compose.ui.zIndex
import com.example.shawarma.data.db.AppDatabase
import com.example.shawarma.data.models.OrderStatus
import com.example.shawarma.data.models.OrderWithProducts
import com.example.shawarma.ui.theme.MarckFamily
import com.example.shawarma.ui.theme.MyLightYellow
import com.example.shawarma.ui.theme.MyMainBackground
import com.example.shawarma.ui.theme.MyOrange
import com.example.shawarma.ui.theme.NunitoFamily
import com.example.shawarma.widgets.ShawarmaLogo2
import kotlinx.coroutines.Dispatchers
import kotlinx.coroutines.withContext
import java.text.SimpleDateFormat

@Composable
fun OrdersScreen() {
    Box(
        contentAlignment = Alignment.Center
    ) {
        ShawarmaLogo2()
        OrdersList()
    }
}

@Composable
fun OrdersList(){
    val context = LocalContext.current
    val allOrders = remember { mutableStateListOf<OrderWithProducts>() }
    LaunchedEffect(Unit) {
        withContext(Dispatchers.IO) {
            AppDatabase.getInstance(context).orderDao().getAll().collect { data ->
                allOrders.clear()
                allOrders.addAll(data)
            }
        }
    }

    val preparingOrders = mutableListOf<OrderWithProducts>()
    val preparedOrders = mutableListOf<OrderWithProducts>()
    val processedOrders = mutableListOf<OrderWithProducts>()

    for (order in allOrders){
        if (order.order.status == OrderStatus.Готовится.toString()) {
            preparingOrders.add(order)
        }
        if (order.order.status == OrderStatus.Готово.toString()) {
            preparedOrders.add(order)
        }
        if (order.order.status == OrderStatus.Выдано.toString()) {
            processedOrders.add(order)
        }
    }


    Box(
        modifier = Modifier
            .clip(shape = RoundedCornerShape(30.dp))
            .padding(top = 100.dp)
            .fillMaxSize()
            .background(color = MyMainBackground)
            .zIndex(2f),

        contentAlignment = Alignment.TopCenter
    ) {
        Text(
            text = "Заказы",
            fontFamily = MarckFamily,
            fontSize = 40.sp,
            modifier = Modifier.padding(top = 15.dp)
        )

        Column(
            horizontalAlignment = Alignment.CenterHorizontally,
            modifier = Modifier
                .fillMaxWidth()
                .padding(top = 55.dp)
                .verticalScroll(rememberScrollState())
        ){
            Text(
                text = "Готовится:",
                fontFamily = NunitoFamily,
                fontSize = 20.sp,
                modifier = Modifier.padding(top = 15.dp),
                fontWeight = FontWeight.Bold
            )
            LazyColumn(
                modifier = Modifier
                    .width(340.dp)
                    .height(250.dp)
            ) {
                if (preparingOrders.size != 0) {
                    items(preparingOrders.size) {
                            index ->
                        PreparingItem(preparingOrders[index])
                    }
                }
            }
            Text(
                text = "Готово:",
                fontFamily = NunitoFamily,
                fontSize = 20.sp,
                modifier = Modifier.padding(top = 15.dp),
                fontWeight = FontWeight.Bold
            )
            LazyColumn(
                modifier = Modifier
                    .width(340.dp)
                    .height(250.dp)
            ) {
                if (preparedOrders.size != 0) {
                    items(preparedOrders.size) {
                            index ->
                        PreparedItem(preparedOrders[index])
                    }
                }
            }
            Text(
                text = "Выдано:",
                fontFamily = NunitoFamily,
                fontSize = 20.sp,
                modifier = Modifier.padding(top = 15.dp),
                fontWeight = FontWeight.Bold
            )
            LazyColumn(
                modifier = Modifier
                    .width(340.dp)
                    .height(250.dp)
            ) {
                if (processedOrders.size != 0) {
                    items(processedOrders.size) {index ->
                        ProcessedItem(processedOrders[index])
                    }
                }
            }
            Spacer(modifier = Modifier.height(70.dp))
        }


    }
}

@Composable
fun PreparingItem(order : OrderWithProducts){
    Card(
        border = BorderStroke(width = 2.dp, color = MyOrange),
        shape = RoundedCornerShape(size = 20.dp),
        backgroundColor = Color.White,
        modifier = Modifier.size(340.dp, 100.dp)
    ){
        Row(
            verticalAlignment = Alignment.CenterVertically,
            horizontalArrangement = Arrangement.SpaceBetween,
            modifier = Modifier.padding(20.dp)
        ){
            Column(

                modifier = Modifier.fillMaxWidth(0.5f)
            ){
                val localDateFormat = SimpleDateFormat("HH:mm")
                val time = localDateFormat.format(order.order.date)
                Text(
                    text = time,
                    fontFamily = NunitoFamily,
                    fontSize = 20.sp,
                    fontWeight = FontWeight.Bold
                )
                Row(
                    horizontalArrangement = Arrangement.SpaceBetween,
                    modifier = Modifier.fillMaxWidth()
                ){
                    Text(
                        text = order.orderWithProducts[0].productList[0].title,
                        fontFamily = NunitoFamily,
                        fontSize = 20.sp,
                        fontWeight = FontWeight.Bold
                    )
                    Text(
                        text = "x" + order.orderWithProducts[0].orderProductModel.quantity,
                        fontFamily = NunitoFamily,
                        fontSize = 20.sp,
                        fontWeight = FontWeight.Bold
                    )
                }
            }


            Button(
                colors = ButtonDefaults.buttonColors(
                    backgroundColor = MyLightYellow
                ),
                shape = RoundedCornerShape(size = 10.dp),
                modifier = Modifier
                    .size(100.dp, 60.dp)
                    .fillMaxSize(0.5f),
                onClick = { /*TODO*/ }
            ) {
                Text(
                    text = "Готово!",
                    fontFamily = NunitoFamily,
                    fontSize = 14.sp,
                    fontWeight = FontWeight.Bold
                )
            }
        }
    }

    Spacer(modifier = Modifier.height(20.dp))
}

@Composable
fun PreparedItem(order : OrderWithProducts){
    Card(
        border = BorderStroke(width = 2.dp, color = MyOrange),
        shape = RoundedCornerShape(size = 20.dp),
        backgroundColor = Color.White,
        modifier = Modifier.size(340.dp, 100.dp)
    ){
        Row(
            verticalAlignment = Alignment.CenterVertically,
            horizontalArrangement = Arrangement.SpaceBetween,
            modifier = Modifier.padding(20.dp)
        ){
            Column(

                modifier = Modifier.fillMaxWidth(0.5f)
            ){
                val localDateFormat = SimpleDateFormat("HH:mm")
                val time = localDateFormat.format(order.order.date)
                Text(
                    text = time,
                    fontFamily = NunitoFamily,
                    fontSize = 20.sp,
                    fontWeight = FontWeight.Bold
                )
                Row(
                    horizontalArrangement = Arrangement.SpaceBetween,
                    modifier = Modifier.fillMaxWidth()
                ){
                    Text(
                        text = order.orderWithProducts[0].productList[0].title,
                        fontFamily = NunitoFamily,
                        fontSize = 20.sp,
                        fontWeight = FontWeight.Bold
                    )
                    Text(
                        text = "x" + order.orderWithProducts[0].orderProductModel.quantity,
                        fontFamily = NunitoFamily,
                        fontSize = 20.sp,
                        fontWeight = FontWeight.Bold
                    )
                }
            }


            Button(
                colors = ButtonDefaults.buttonColors(
                    backgroundColor = MyLightYellow
                ),
                shape = RoundedCornerShape(size = 10.dp),
                modifier = Modifier
                    .size(100.dp, 60.dp)
                    .fillMaxSize(0.5f),
                onClick = { /*TODO*/ }
            ) {
                Text(
                    text = "Выдано!",
                    fontFamily = NunitoFamily,
                    fontSize = 14.sp,
                    fontWeight = FontWeight.Bold
                )
            }
        }
    }

    Spacer(modifier = Modifier.height(20.dp))
}

@Composable
fun ProcessedItem(order : OrderWithProducts){
    Card(
        border = BorderStroke(width = 2.dp, color = MyOrange),
        shape = RoundedCornerShape(size = 20.dp),
        backgroundColor = Color.White,
        modifier = Modifier.size(340.dp, 100.dp)
    ){
        Row(
            verticalAlignment = Alignment.CenterVertically,
            horizontalArrangement = Arrangement.SpaceBetween,
            modifier = Modifier.padding(20.dp)
        ){
            Column(

                modifier = Modifier.fillMaxWidth(0.5f)
            ){
                val localDateFormat = SimpleDateFormat("HH:mm")
                val time = localDateFormat.format(order.order.date)
                Text(
                    text = time,
                    fontFamily = NunitoFamily,
                    fontSize = 20.sp,
                    fontWeight = FontWeight.Bold
                )
                Row(
                    horizontalArrangement = Arrangement.SpaceBetween,
                    modifier = Modifier.fillMaxWidth()
                ){
                    Text(
                        text = order.orderWithProducts[0].productList[0].title,
                        fontFamily = NunitoFamily,
                        fontSize = 20.sp,
                        fontWeight = FontWeight.Bold
                    )
                    Text(
                        text = "x" + order.orderWithProducts[0].orderProductModel.quantity,
                        fontFamily = NunitoFamily,
                        fontSize = 20.sp,
                        fontWeight = FontWeight.Bold
                    )
                }
            }


            Column(

                modifier = Modifier.fillMaxWidth(0.5f)
            ){
                Text(
                    text = order.orderWithProducts[0].orderProductModel.totalPrice.toString(),
                    fontFamily = NunitoFamily,
                    fontSize = 14.sp,
                    fontWeight = FontWeight.Bold
                )
                Text(
                    text = order.order.date.toString(),
                    fontFamily = NunitoFamily,
                    fontSize = 14.sp,
                    fontWeight = FontWeight.Bold
                )
            }
        }
    }

    Spacer(modifier = Modifier.height(20.dp))
}